"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TriggerTypeEnum(str, Enum):
    r"""The type of the trigger"""

    EVENT = "event"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getsubscriberpreferencesresponsedto import (
    GetSubscriberPreferencesResponseDto,
    GetSubscriberPreferencesResponseDtoTypedDict,
)
from enum import Enum
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    QueryParamMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class Parameter(str, Enum):
    r"""the preferences level to be retrieved (template / global)"""

    GLOBAL = "global"
    TEMPLATE = "template"


class SubscribersV1ControllerGetSubscriberPreferenceByLevelRequestTypedDict(TypedDict):
    preference_level: Parameter
    r"""the preferences level to be retrieved (template / global)"""
    subscriber_id: str
    include_inactive_channels: NotRequired[bool]
    r"""A flag which specifies if the inactive workflow channels should be included in the retrieved preferences. Default is true"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class SubscribersV1ControllerGetSubscriberPreferenceByLevelRequest(BaseModel):
    preference_level: Annotated[
        Parameter,
        pydantic.Field(alias="parameter"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""the preferences level to be retrieved (template / global)"""

    subscriber_id: Annotated[
        str,
        pydantic.Field(alias="subscriberId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    include_inactive_channels: Annotated[
        Optional[bool],
        pydantic.Field(alias="includeInactiveChannels"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""A flag which specifies if the inactive workflow channels should be included in the retrieved preferences. Default is true"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class SubscribersV1ControllerGetSubscriberPreferenceByLevelResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[GetSubscriberPreferencesResponseDtoTypedDict]


class SubscribersV1ControllerGetSubscriberPreferenceByLevelResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[GetSubscriberPreferencesResponseDto]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .notificationtriggerresponse import (
    NotificationTriggerResponse,
    NotificationTriggerResponseTypedDict,
)
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class TemplateResponseTypedDict(TypedDict):
    id: str
    r"""Unique identifier of the workflow"""
    name: str
    r"""Name of the workflow"""
    critical: bool
    r"""Critical templates will always be delivered to the end user and should be hidden from the subscriber preferences screen"""
    triggers: List[NotificationTriggerResponseTypedDict]
    r"""Triggers are the events that will trigger the workflow."""


class TemplateResponse(BaseModel):
    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""Unique identifier of the workflow"""

    name: str
    r"""Name of the workflow"""

    critical: bool
    r"""Critical templates will always be delivered to the end user and should be hidden from the subscriber preferences screen"""

    triggers: List[NotificationTriggerResponse]
    r"""Triggers are the events that will trigger the workflow."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class CreateTopicRequestDtoTypedDict(TypedDict):
    key: str
    r"""User defined custom key and provided by the user that will be an unique identifier for the Topic created."""
    name: str
    r"""User defined custom name and provided by the user that will name the Topic created."""


class CreateTopicRequestDto(BaseModel):
    key: str
    r"""User defined custom key and provided by the user that will be an unique identifier for the Topic created."""

    name: str
    r"""User defined custom name and provided by the user that will name the Topic created."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py import utils
from novu_py.types import BaseModel, Nullable, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, List, Optional, Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


ValidationErrorDtoValueTypedDict = TypeAliasType(
    "ValidationErrorDtoValueTypedDict",
    Union[str, float, bool, Dict[str, Any], List[Dict[str, Any]]],
)


ValidationErrorDtoValue = TypeAliasType(
    "ValidationErrorDtoValue",
    Union[str, float, bool, Dict[str, Any], List[Dict[str, Any]]],
)


class ErrorsTypedDict(TypedDict):
    messages: List[str]
    value: Nullable[ValidationErrorDtoValueTypedDict]


class Errors(BaseModel):
    messages: List[str]

    value: Nullable[ValidationErrorDtoValue]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["value"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ValidationErrorDtoData(BaseModel):
    status_code: Annotated[float, pydantic.Field(alias="statusCode")]
    r"""HTTP status code of the error response."""

    timestamp: str
    r"""Timestamp of when the error occurred."""

    path: str
    r"""The path where the error occurred."""

    message: str
    r"""A detailed error message."""

    errors: Dict[str, Errors]
    r"""A record of validation errors keyed by field name"""

    ctx: Optional[Dict[str, Any]] = None
    r"""Optional context object for additional error details."""

    error_id: Annotated[Optional[str], pydantic.Field(alias="errorId")] = None
    r"""Optional unique identifier for the error, useful for tracking using Sentry and
    New Relic, only available for 500.
    """


class ValidationErrorDto(Exception):
    data: ValidationErrorDtoData

    def __init__(self, data: ValidationErrorDtoData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, ValidationErrorDtoData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .channeltypeenum import ChannelTypeEnum
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class ChannelPreferenceTypedDict(TypedDict):
    type: ChannelTypeEnum
    r"""Channel type through which the message is sent"""
    enabled: bool
    r"""If channel is enabled or not"""


class ChannelPreference(BaseModel):
    type: ChannelTypeEnum
    r"""Channel type through which the message is sent"""

    enabled: bool
    r"""If channel is enabled or not"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .addsubscribersrequestdto import (
    AddSubscribersRequestDto,
    AddSubscribersRequestDtoTypedDict,
)
from .assignsubscribertotopicdto import (
    AssignSubscriberToTopicDto,
    AssignSubscriberToTopicDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TopicsControllerAssignRequestTypedDict(TypedDict):
    topic_key: str
    r"""The topic key"""
    add_subscribers_request_dto: AddSubscribersRequestDtoTypedDict
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class TopicsControllerAssignRequest(BaseModel):
    topic_key: Annotated[
        str,
        pydantic.Field(alias="topicKey"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The topic key"""

    add_subscribers_request_dto: Annotated[
        AddSubscribersRequestDto,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class TopicsControllerAssignResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: AssignSubscriberToTopicDtoTypedDict


class TopicsControllerAssignResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: AssignSubscriberToTopicDto



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from novu_py import models, utils
from novu_py._hooks import HookContext
from novu_py.types import OptionalNullable, UNSET
from novu_py.utils import get_security_from_env
from novu_py.webhooks import Webhooks
from typing import Any, List, Mapping, Optional, Union


class Integrations(BaseSDK):
    r"""With the help of the Integration Store, you can easily integrate your favorite delivery provider. During the runtime of the API, the Integrations Store is responsible for storing the configurations of all the providers.
    https://docs.novu.co/channels-and-providers/integration-store
    """

    webhooks: Webhooks

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.webhooks = Webhooks(self.sdk_configuration)

    def list(
        self,
        *,
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerListIntegrationsResponse:
        r"""Get integrations

        Return all the integrations the user has created for that organization. Review v.0.17.0 changelog for a breaking change

        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerListIntegrationsRequest(
            idempotency_key=idempotency_key,
        )

        req = self._build_request(
            method="GET",
            path="/v1/integrations",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_listIntegrations",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerListIntegrationsResponse(
                result=utils.unmarshal_json(
                    http_res.text, List[models.IntegrationResponseDto]
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "404", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, "429", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_async(
        self,
        *,
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerListIntegrationsResponse:
        r"""Get integrations

        Return all the integrations the user has created for that organization. Review v.0.17.0 changelog for a breaking change

        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerListIntegrationsRequest(
            idempotency_key=idempotency_key,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/integrations",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_listIntegrations",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerListIntegrationsResponse(
                result=utils.unmarshal_json(
                    http_res.text, List[models.IntegrationResponseDto]
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "404", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, "429", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def create(
        self,
        *,
        create_integration_request_dto: Union[
            models.CreateIntegrationRequestDto,
            models.CreateIntegrationRequestDtoTypedDict,
        ],
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerCreateIntegrationResponse:
        r"""Create integration

        Create an integration for the current environment the user is based on the API key provided

        :param create_integration_request_dto:
        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerCreateIntegrationRequest(
            idempotency_key=idempotency_key,
            create_integration_request_dto=utils.get_pydantic_model(
                create_integration_request_dto, models.CreateIntegrationRequestDto
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1/integrations",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.create_integration_request_dto,
                False,
                False,
                "json",
                models.CreateIntegrationRequestDto,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_createIntegration",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return models.IntegrationsControllerCreateIntegrationResponse(
                result=utils.unmarshal_json(
                    http_res.text, models.IntegrationResponseDto
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "404", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, "429", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def create_async(
        self,
        *,
        create_integration_request_dto: Union[
            models.CreateIntegrationRequestDto,
            models.CreateIntegrationRequestDtoTypedDict,
        ],
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerCreateIntegrationResponse:
        r"""Create integration

        Create an integration for the current environment the user is based on the API key provided

        :param create_integration_request_dto:
        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerCreateIntegrationRequest(
            idempotency_key=idempotency_key,
            create_integration_request_dto=utils.get_pydantic_model(
                create_integration_request_dto, models.CreateIntegrationRequestDto
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/integrations",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.create_integration_request_dto,
                False,
                False,
                "json",
                models.CreateIntegrationRequestDto,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_createIntegration",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return models.IntegrationsControllerCreateIntegrationResponse(
                result=utils.unmarshal_json(
                    http_res.text, models.IntegrationResponseDto
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "404", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, "429", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def list_active(
        self,
        *,
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerGetActiveIntegrationsResponse:
        r"""Get active integrations

        Return all the active integrations the user has created for that organization. Review v.0.17.0 changelog for a breaking change

        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerGetActiveIntegrationsRequest(
            idempotency_key=idempotency_key,
        )

        req = self._build_request(
            method="GET",
            path="/v1/integrations/active",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_getActiveIntegrations",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerGetActiveIntegrationsResponse(
                result=utils.unmarshal_json(
                    http_res.text, List[models.IntegrationResponseDto]
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "404", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, "429", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_active_async(
        self,
        *,
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerGetActiveIntegrationsResponse:
        r"""Get active integrations

        Return all the active integrations the user has created for that organization. Review v.0.17.0 changelog for a breaking change

        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerGetActiveIntegrationsRequest(
            idempotency_key=idempotency_key,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/integrations/active",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_getActiveIntegrations",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerGetActiveIntegrationsResponse(
                result=utils.unmarshal_json(
                    http_res.text, List[models.IntegrationResponseDto]
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "404", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, "429", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def update(
        self,
        *,
        integration_id: str,
        update_integration_request_dto: Union[
            models.UpdateIntegrationRequestDto,
            models.UpdateIntegrationRequestDtoTypedDict,
        ],
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerUpdateIntegrationByIDResponse:
        r"""Update integration

        :param integration_id:
        :param update_integration_request_dto:
        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerUpdateIntegrationByIDRequest(
            integration_id=integration_id,
            idempotency_key=idempotency_key,
            update_integration_request_dto=utils.get_pydantic_model(
                update_integration_request_dto, models.UpdateIntegrationRequestDto
            ),
        )

        req = self._build_request(
            method="PUT",
            path="/v1/integrations/{integrationId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.update_integration_request_dto,
                False,
                False,
                "json",
                models.UpdateIntegrationRequestDto,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_updateIntegrationById",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerUpdateIntegrationByIDResponse(
                result=utils.unmarshal_json(
                    http_res.text, models.IntegrationResponseDto
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, ["404", "429"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def update_async(
        self,
        *,
        integration_id: str,
        update_integration_request_dto: Union[
            models.UpdateIntegrationRequestDto,
            models.UpdateIntegrationRequestDtoTypedDict,
        ],
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerUpdateIntegrationByIDResponse:
        r"""Update integration

        :param integration_id:
        :param update_integration_request_dto:
        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerUpdateIntegrationByIDRequest(
            integration_id=integration_id,
            idempotency_key=idempotency_key,
            update_integration_request_dto=utils.get_pydantic_model(
                update_integration_request_dto, models.UpdateIntegrationRequestDto
            ),
        )

        req = self._build_request_async(
            method="PUT",
            path="/v1/integrations/{integrationId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.update_integration_request_dto,
                False,
                False,
                "json",
                models.UpdateIntegrationRequestDto,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_updateIntegrationById",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerUpdateIntegrationByIDResponse(
                result=utils.unmarshal_json(
                    http_res.text, models.IntegrationResponseDto
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, ["404", "429"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def delete(
        self,
        *,
        integration_id: str,
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerRemoveIntegrationResponse:
        r"""Delete integration

        :param integration_id:
        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerRemoveIntegrationRequest(
            integration_id=integration_id,
            idempotency_key=idempotency_key,
        )

        req = self._build_request(
            method="DELETE",
            path="/v1/integrations/{integrationId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_removeIntegration",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerRemoveIntegrationResponse(
                result=utils.unmarshal_json(
                    http_res.text, List[models.IntegrationResponseDto]
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "404", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, "429", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def delete_async(
        self,
        *,
        integration_id: str,
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerRemoveIntegrationResponse:
        r"""Delete integration

        :param integration_id:
        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerRemoveIntegrationRequest(
            integration_id=integration_id,
            idempotency_key=idempotency_key,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/v1/integrations/{integrationId}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_removeIntegration",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerRemoveIntegrationResponse(
                result=utils.unmarshal_json(
                    http_res.text, List[models.IntegrationResponseDto]
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "404", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, "429", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def set_as_primary(
        self,
        *,
        integration_id: str,
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerSetIntegrationAsPrimaryResponse:
        r"""Set integration as primary

        :param integration_id:
        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerSetIntegrationAsPrimaryRequest(
            integration_id=integration_id,
            idempotency_key=idempotency_key,
        )

        req = self._build_request(
            method="POST",
            path="/v1/integrations/{integrationId}/set-primary",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_setIntegrationAsPrimary",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerSetIntegrationAsPrimaryResponse(
                result=utils.unmarshal_json(
                    http_res.text, models.IntegrationResponseDto
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, ["404", "429"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def set_as_primary_async(
        self,
        *,
        integration_id: str,
        idempotency_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.IntegrationsControllerSetIntegrationAsPrimaryResponse:
        r"""Set integration as primary

        :param integration_id:
        :param idempotency_key: A header for idempotency purposes
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.IntegrationsControllerSetIntegrationAsPrimaryRequest(
            integration_id=integration_id,
            idempotency_key=idempotency_key,
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/integrations/{integrationId}/set-primary",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(1000, 30000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["408", "409", "429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="IntegrationsController_setIntegrationAsPrimary",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "405",
                "409",
                "413",
                "414",
                "415",
                "422",
                "429",
                "4XX",
                "500",
                "503",
                "5XX",
            ],
            retry_config=retry_config,
        )

        data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.IntegrationsControllerSetIntegrationAsPrimaryResponse(
                result=utils.unmarshal_json(
                    http_res.text, models.IntegrationResponseDto
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, "414", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(
            http_res,
            ["400", "401", "403", "405", "409", "413", "415"],
            "application/json",
        ):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "422", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ValidationErrorDtoData)
            raise models.ValidationErrorDto(data=data)
        if utils.match_response(http_res, ["404", "429"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "500", "application/json"):
            data = utils.unmarshal_json(http_res.text, models.ErrorDtoData)
            raise models.ErrorDto(data=data)
        if utils.match_response(http_res, "503", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class Channels(str, Enum):
    IN_APP = "in_app"
    EMAIL = "email"
    SMS = "sms"
    CHAT = "chat"
    PUSH = "push"


class ActivityGraphStatesResponseTypedDict(TypedDict):
    id: str
    count: float
    templates: List[str]
    channels: List[Channels]


class ActivityGraphStatesResponse(BaseModel):
    id: Annotated[str, pydantic.Field(alias="_id")]

    count: float

    templates: List[str]

    channels: List[Channels]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .topicdto import TopicDto, TopicDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class FilterTopicsResponseDtoTypedDict(TypedDict):
    data: List[TopicDtoTypedDict]
    r"""The list of topics"""
    page: float
    r"""The current page number"""
    page_size: float
    r"""The number of items per page"""
    total_count: float
    r"""The total number of items"""


class FilterTopicsResponseDto(BaseModel):
    data: List[TopicDto]
    r"""The list of topics"""

    page: float
    r"""The current page number"""

    page_size: Annotated[float, pydantic.Field(alias="pageSize")]
    r"""The number of items per page"""

    total_count: Annotated[float, pydantic.Field(alias="totalCount")]
    r"""The total number of items"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .integrationresponsedto import (
    IntegrationResponseDto,
    IntegrationResponseDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IntegrationsControllerListIntegrationsRequestTypedDict(TypedDict):
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class IntegrationsControllerListIntegrationsRequest(BaseModel):
    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class IntegrationsControllerListIntegrationsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[IntegrationResponseDtoTypedDict]


class IntegrationsControllerListIntegrationsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[IntegrationResponseDto]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .channelpreference import ChannelPreference, ChannelPreferenceTypedDict
from novu_py.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class UpdateSubscriberGlobalPreferencesRequestDtoTypedDict(TypedDict):
    enabled: NotRequired[bool]
    r"""Enable or disable the subscriber global preferences."""
    preferences: NotRequired[List[ChannelPreferenceTypedDict]]
    r"""The subscriber global preferences for every ChannelTypeEnum."""


class UpdateSubscriberGlobalPreferencesRequestDto(BaseModel):
    enabled: Optional[bool] = None
    r"""Enable or disable the subscriber global preferences."""

    preferences: Optional[List[ChannelPreference]] = None
    r"""The subscriber global preferences for every ChannelTypeEnum."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriberresponsedto import SubscriberResponseDto, SubscriberResponseDtoTypedDict
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, QueryParamMetadata
import pydantic
from typing import Callable, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SubscribersV1ControllerListSubscribersRequestTypedDict(TypedDict):
    page: NotRequired[float]
    limit: NotRequired[float]
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class SubscribersV1ControllerListSubscribersRequest(BaseModel):
    page: Annotated[
        Optional[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    limit: Annotated[
        Optional[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 10

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class SubscribersV1ControllerListSubscribersResponseBodyTypedDict(TypedDict):
    page: float
    r"""The current page of the paginated response"""
    has_more: bool
    r"""Does the list have more items to fetch"""
    page_size: float
    r"""Number of items on each page"""
    data: List[SubscriberResponseDtoTypedDict]


class SubscribersV1ControllerListSubscribersResponseBody(BaseModel):
    page: float
    r"""The current page of the paginated response"""

    has_more: Annotated[bool, pydantic.Field(alias="hasMore")]
    r"""Does the list have more items to fetch"""

    page_size: Annotated[float, pydantic.Field(alias="pageSize")]
    r"""Number of items on each page"""

    data: List[SubscriberResponseDto]


class SubscribersV1ControllerListSubscribersResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: SubscribersV1ControllerListSubscribersResponseBodyTypedDict


class SubscribersV1ControllerListSubscribersResponse(BaseModel):
    next: Callable[[], Optional[SubscribersV1ControllerListSubscribersResponse]]

    headers: Dict[str, List[str]]

    result: SubscribersV1ControllerListSubscribersResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .failedassignmentsdto import FailedAssignmentsDto, FailedAssignmentsDtoTypedDict
from novu_py.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class AssignSubscriberToTopicDtoTypedDict(TypedDict):
    succeeded: List[str]
    r"""List of successfully assigned subscriber IDs"""
    failed: NotRequired[FailedAssignmentsDtoTypedDict]
    r"""Details about failed assignments"""


class AssignSubscriberToTopicDto(BaseModel):
    succeeded: List[str]
    r"""List of successfully assigned subscriber IDs"""

    failed: Optional[FailedAssignmentsDto] = None
    r"""Details about failed assignments"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class RenameTopicRequestDtoTypedDict(TypedDict):
    name: str
    r"""User defined custom name and provided by the user to rename the topic."""


class RenameTopicRequestDto(BaseModel):
    name: str
    r"""User defined custom name and provided by the user to rename the topic."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class DataBooleanDtoTypedDict(TypedDict):
    data: bool


class DataBooleanDto(BaseModel):
    data: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriberpayloaddto import SubscriberPayloadDto, SubscriberPayloadDtoTypedDict
from .tenantpayloaddto import TenantPayloadDto, TenantPayloadDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class OverridesTypedDict(TypedDict):
    r"""This could be used to override provider specific configurations"""


class Overrides(BaseModel):
    r"""This could be used to override provider specific configurations"""


TriggerEventToAllRequestDtoActorTypedDict = TypeAliasType(
    "TriggerEventToAllRequestDtoActorTypedDict",
    Union[SubscriberPayloadDtoTypedDict, str],
)
r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.
If a new actor object is provided, we will create a new subscriber in our system

"""


TriggerEventToAllRequestDtoActor = TypeAliasType(
    "TriggerEventToAllRequestDtoActor", Union[SubscriberPayloadDto, str]
)
r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.
If a new actor object is provided, we will create a new subscriber in our system

"""


TriggerEventToAllRequestDtoTenantTypedDict = TypeAliasType(
    "TriggerEventToAllRequestDtoTenantTypedDict", Union[TenantPayloadDtoTypedDict, str]
)
r"""It is used to specify a tenant context during trigger event.
If a new tenant object is provided, we will create a new tenant.

"""


TriggerEventToAllRequestDtoTenant = TypeAliasType(
    "TriggerEventToAllRequestDtoTenant", Union[TenantPayloadDto, str]
)
r"""It is used to specify a tenant context during trigger event.
If a new tenant object is provided, we will create a new tenant.

"""


class TriggerEventToAllRequestDtoTypedDict(TypedDict):
    name: str
    r"""The trigger identifier associated for the template you wish to send. This identifier can be found on the template page."""
    payload: Dict[str, Any]
    r"""The payload object is used to pass additional information that
    could be used to render the template, or perform routing rules based on it.
    For In-App channel, payload data are also available in <Inbox />
    """
    overrides: NotRequired[OverridesTypedDict]
    r"""This could be used to override provider specific configurations"""
    transaction_id: NotRequired[str]
    r"""A unique identifier for this transaction, we will generated a UUID if not provided."""
    actor: NotRequired[TriggerEventToAllRequestDtoActorTypedDict]
    r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.
    If a new actor object is provided, we will create a new subscriber in our system

    """
    tenant: NotRequired[TriggerEventToAllRequestDtoTenantTypedDict]
    r"""It is used to specify a tenant context during trigger event.
    If a new tenant object is provided, we will create a new tenant.

    """


class TriggerEventToAllRequestDto(BaseModel):
    name: str
    r"""The trigger identifier associated for the template you wish to send. This identifier can be found on the template page."""

    payload: Dict[str, Any]
    r"""The payload object is used to pass additional information that
    could be used to render the template, or perform routing rules based on it.
    For In-App channel, payload data are also available in <Inbox />
    """

    overrides: Optional[Overrides] = None
    r"""This could be used to override provider specific configurations"""

    transaction_id: Annotated[Optional[str], pydantic.Field(alias="transactionId")] = (
        None
    )
    r"""A unique identifier for this transaction, we will generated a UUID if not provided."""

    actor: Optional[TriggerEventToAllRequestDtoActor] = None
    r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.
    If a new actor object is provided, we will create a new subscriber in our system

    """

    tenant: Optional[TriggerEventToAllRequestDtoTenant] = None
    r"""It is used to specify a tenant context during trigger event.
    If a new tenant object is provided, we will create a new tenant.

    """



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class TriggerReservedVariableResponseType(str, Enum):
    r"""The type of the reserved variable"""

    TENANT = "tenant"
    ACTOR = "actor"


class TriggerReservedVariableResponseTypedDict(TypedDict):
    type: TriggerReservedVariableResponseType
    r"""The type of the reserved variable"""
    variables: List[str]
    r"""The reserved variables of the trigger"""


class TriggerReservedVariableResponse(BaseModel):
    type: TriggerReservedVariableResponseType
    r"""The type of the reserved variable"""

    variables: List[str]
    r"""The reserved variables of the trigger"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .activitiesresponsedto import ActivitiesResponseDto, ActivitiesResponseDtoTypedDict
from .activitygraphstatesresponse import (
    ActivityGraphStatesResponse,
    ActivityGraphStatesResponseTypedDict,
    Channels,
)
from .activitynotificationexecutiondetailresponsedto import (
    ActivityNotificationExecutionDetailResponseDto,
    ActivityNotificationExecutionDetailResponseDtoTypedDict,
)
from .activitynotificationjobresponsedto import (
    ActivityNotificationJobResponseDto,
    ActivityNotificationJobResponseDtoType,
    ActivityNotificationJobResponseDtoTypedDict,
    Payload,
    PayloadTypedDict,
)
from .activitynotificationresponsedto import (
    ActivityNotificationResponseDto,
    ActivityNotificationResponseDtoPayload,
    ActivityNotificationResponseDtoPayloadTypedDict,
    ActivityNotificationResponseDtoTo,
    ActivityNotificationResponseDtoToTypedDict,
    ActivityNotificationResponseDtoTypedDict,
    Controls,
    ControlsTypedDict,
)
from .activitynotificationstepresponsedto import (
    ActivityNotificationStepResponseDto,
    ActivityNotificationStepResponseDtoReplyCallback,
    ActivityNotificationStepResponseDtoReplyCallbackTypedDict,
    ActivityNotificationStepResponseDtoTypedDict,
    ControlVariables,
    ControlVariablesTypedDict,
    Issues,
    IssuesTypedDict,
    Metadata,
    MetadataTypedDict,
)
from .activitynotificationsubscriberresponsedto import (
    ActivityNotificationSubscriberResponseDto,
    ActivityNotificationSubscriberResponseDtoTypedDict,
)
from .activitynotificationtemplateresponsedto import (
    ActivityNotificationTemplateResponseDto,
    ActivityNotificationTemplateResponseDtoTypedDict,
)
from .activitystatsresponsedto import (
    ActivityStatsResponseDto,
    ActivityStatsResponseDtoTypedDict,
)
from .actorfeeditemdto import ActorFeedItemDto, ActorFeedItemDtoTypedDict
from .actortypeenum import ActorTypeEnum
from .addsubscribersrequestdto import (
    AddSubscribersRequestDto,
    AddSubscribersRequestDtoTypedDict,
)
from .apierror import APIError
from .assignsubscribertotopicdto import (
    AssignSubscriberToTopicDto,
    AssignSubscriberToTopicDtoTypedDict,
)
from .builderfieldtypeenum import BuilderFieldTypeEnum
from .bulkcreatesubscriberresponsedto import (
    BulkCreateSubscriberResponseDto,
    BulkCreateSubscriberResponseDtoTypedDict,
)
from .bulksubscribercreatedto import (
    BulkSubscriberCreateDto,
    BulkSubscriberCreateDtoTypedDict,
)
from .bulktriggereventdto import BulkTriggerEventDto, BulkTriggerEventDtoTypedDict
from .buttontypeenum import ButtonTypeEnum
from .channelcredentials import ChannelCredentials, ChannelCredentialsTypedDict
from .channelcredentialsdto import ChannelCredentialsDto, ChannelCredentialsDtoTypedDict
from .channelctatypeenum import ChannelCTATypeEnum
from .channelpreference import ChannelPreference, ChannelPreferenceTypedDict
from .channelsettingsdto import (
    ChannelSettingsDto,
    ChannelSettingsDtoProviderID,
    ChannelSettingsDtoTypedDict,
)
from .channeltypeenum import ChannelTypeEnum
from .createdsubscriberdto import CreatedSubscriberDto, CreatedSubscriberDtoTypedDict
from .createintegrationrequestdto import (
    CreateIntegrationRequestDto,
    CreateIntegrationRequestDtoChannel,
    CreateIntegrationRequestDtoTypedDict,
)
from .createsubscriberrequestdto import (
    CreateSubscriberRequestDto,
    CreateSubscriberRequestDtoData,
    CreateSubscriberRequestDtoDataTypedDict,
    CreateSubscriberRequestDtoTypedDict,
)
from .createtopicrequestdto import CreateTopicRequestDto, CreateTopicRequestDtoTypedDict
from .createtopicresponsedto import (
    CreateTopicResponseDto,
    CreateTopicResponseDtoTypedDict,
)
from .credentialsdto import (
    CredentialsDto,
    CredentialsDtoTypedDict,
    TLSOptions,
    TLSOptionsTypedDict,
)
from .databooleandto import DataBooleanDto, DataBooleanDtoTypedDict
from .delayregularmetadata import (
    DelayRegularMetadata,
    DelayRegularMetadataType,
    DelayRegularMetadataTypedDict,
    DelayRegularMetadataUnit,
)
from .delayscheduledmetadata import (
    DelayScheduledMetadata,
    DelayScheduledMetadataType,
    DelayScheduledMetadataTypedDict,
)
from .deletemessageresponsedto import (
    DeleteMessageResponseDto,
    DeleteMessageResponseDtoStatus,
    DeleteMessageResponseDtoTypedDict,
)
from .deletesubscriberresponsedto import (
    DeleteSubscriberResponseDto,
    DeleteSubscriberResponseDtoStatus,
    DeleteSubscriberResponseDtoTypedDict,
)
from .digestmetadatadto import DigestMetadataDto, DigestMetadataDtoTypedDict, Unit
from .digestregularmetadata import (
    BackoffUnit,
    DigestRegularMetadata,
    DigestRegularMetadataType,
    DigestRegularMetadataTypedDict,
    DigestRegularMetadataUnit,
)
from .digesttimedconfigdto import (
    DigestTimedConfigDto,
    DigestTimedConfigDtoTypedDict,
    WeekDays,
)
from .digesttimedmetadata import (
    DigestTimedMetadata,
    DigestTimedMetadataType,
    DigestTimedMetadataTypedDict,
    DigestTimedMetadataUnit,
)
from .digesttypeenum import DigestTypeEnum
from .digestunitenum import DigestUnitEnum
from .emailblock import EmailBlock, EmailBlockTypedDict
from .emailblockstyles import EmailBlockStyles, EmailBlockStylesTypedDict
from .emailblocktypeenum import EmailBlockTypeEnum
from .errordto import ErrorDto, ErrorDtoData
from .eventscontroller_broadcasteventtoallop import (
    EventsControllerBroadcastEventToAllRequest,
    EventsControllerBroadcastEventToAllRequestTypedDict,
    EventsControllerBroadcastEventToAllResponse,
    EventsControllerBroadcastEventToAllResponseTypedDict,
)
from .eventscontroller_cancelop import (
    EventsControllerCancelRequest,
    EventsControllerCancelRequestTypedDict,
    EventsControllerCancelResponse,
    EventsControllerCancelResponseTypedDict,
)
from .eventscontroller_triggerbulkop import (
    EventsControllerTriggerBulkRequest,
    EventsControllerTriggerBulkRequestTypedDict,
    EventsControllerTriggerBulkResponse,
    EventsControllerTriggerBulkResponseTypedDict,
)
from .eventscontroller_triggerop import (
    EventsControllerTriggerRequest,
    EventsControllerTriggerRequestTypedDict,
    EventsControllerTriggerResponse,
    EventsControllerTriggerResponseTypedDict,
)
from .executiondetailssourceenum import ExecutionDetailsSourceEnum
from .executiondetailsstatusenum import ExecutionDetailsStatusEnum
from .failedassignmentsdto import FailedAssignmentsDto, FailedAssignmentsDtoTypedDict
from .failedoperationdto import FailedOperationDto, FailedOperationDtoTypedDict
from .feedresponsedto import FeedResponseDto, FeedResponseDtoTypedDict
from .fieldfilterpartdto import (
    FieldFilterPartDto,
    FieldFilterPartDtoTypedDict,
    On,
    Operator,
)
from .filtertopicsresponsedto import (
    FilterTopicsResponseDto,
    FilterTopicsResponseDtoTypedDict,
)
from .getsubscriberpreferencesresponsedto import (
    GetSubscriberPreferencesResponseDto,
    GetSubscriberPreferencesResponseDtoTypedDict,
)
from .gettopicresponsedto import GetTopicResponseDto, GetTopicResponseDtoTypedDict
from .integrationresponsedto import (
    Channel,
    IntegrationResponseDto,
    IntegrationResponseDtoTypedDict,
)
from .integrationscontroller_createintegrationop import (
    IntegrationsControllerCreateIntegrationRequest,
    IntegrationsControllerCreateIntegrationRequestTypedDict,
    IntegrationsControllerCreateIntegrationResponse,
    IntegrationsControllerCreateIntegrationResponseTypedDict,
)
from .integrationscontroller_getactiveintegrationsop import (
    IntegrationsControllerGetActiveIntegrationsRequest,
    IntegrationsControllerGetActiveIntegrationsRequestTypedDict,
    IntegrationsControllerGetActiveIntegrationsResponse,
    IntegrationsControllerGetActiveIntegrationsResponseTypedDict,
)
from .integrationscontroller_getwebhooksupportstatusop import (
    IntegrationsControllerGetWebhookSupportStatusRequest,
    IntegrationsControllerGetWebhookSupportStatusRequestTypedDict,
    IntegrationsControllerGetWebhookSupportStatusResponse,
    IntegrationsControllerGetWebhookSupportStatusResponseTypedDict,
)
from .integrationscontroller_listintegrationsop import (
    IntegrationsControllerListIntegrationsRequest,
    IntegrationsControllerListIntegrationsRequestTypedDict,
    IntegrationsControllerListIntegrationsResponse,
    IntegrationsControllerListIntegrationsResponseTypedDict,
)
from .integrationscontroller_removeintegrationop import (
    IntegrationsControllerRemoveIntegrationRequest,
    IntegrationsControllerRemoveIntegrationRequestTypedDict,
    IntegrationsControllerRemoveIntegrationResponse,
    IntegrationsControllerRemoveIntegrationResponseTypedDict,
)
from .integrationscontroller_setintegrationasprimaryop import (
    IntegrationsControllerSetIntegrationAsPrimaryRequest,
    IntegrationsControllerSetIntegrationAsPrimaryRequestTypedDict,
    IntegrationsControllerSetIntegrationAsPrimaryResponse,
    IntegrationsControllerSetIntegrationAsPrimaryResponseTypedDict,
)
from .integrationscontroller_updateintegrationbyidop import (
    IntegrationsControllerUpdateIntegrationByIDRequest,
    IntegrationsControllerUpdateIntegrationByIDRequestTypedDict,
    IntegrationsControllerUpdateIntegrationByIDResponse,
    IntegrationsControllerUpdateIntegrationByIDResponseTypedDict,
)
from .listsubscribersresponsedto import (
    ListSubscribersResponseDto,
    ListSubscribersResponseDtoTypedDict,
)
from .markallmessageasrequestdto import (
    FeedIdentifier,
    FeedIdentifierTypedDict,
    MarkAllMessageAsRequestDto,
    MarkAllMessageAsRequestDtoMarkAs,
    MarkAllMessageAsRequestDtoTypedDict,
)
from .markmessageactionasseendto import (
    MarkMessageActionAsSeenDto,
    MarkMessageActionAsSeenDtoPayload,
    MarkMessageActionAsSeenDtoPayloadTypedDict,
    MarkMessageActionAsSeenDtoStatus,
    MarkMessageActionAsSeenDtoTypedDict,
)
from .messageaction import MessageAction, MessageActionTypedDict
from .messageactionresult import (
    MessageActionResult,
    MessageActionResultPayload,
    MessageActionResultPayloadTypedDict,
    MessageActionResultTypedDict,
)
from .messageactionstatusenum import MessageActionStatusEnum
from .messagebutton import MessageButton, MessageButtonTypedDict
from .messagecta import MessageCTA, MessageCTATypedDict
from .messagectadata import MessageCTAData, MessageCTADataTypedDict
from .messagemarkasrequestdto import (
    MarkAs,
    MessageID,
    MessageIDTypedDict,
    MessageMarkAsRequestDto,
    MessageMarkAsRequestDtoTypedDict,
)
from .messageresponsedto import (
    Content,
    ContentTypedDict,
    MessageResponseDto,
    MessageResponseDtoOverrides,
    MessageResponseDtoOverridesTypedDict,
    MessageResponseDtoPayload,
    MessageResponseDtoPayloadTypedDict,
    MessageResponseDtoTypedDict,
)
from .messagescontroller_deletemessageop import (
    MessagesControllerDeleteMessageRequest,
    MessagesControllerDeleteMessageRequestTypedDict,
    MessagesControllerDeleteMessageResponse,
    MessagesControllerDeleteMessageResponseTypedDict,
)
from .messagescontroller_deletemessagesbytransactionidop import (
    MessagesControllerDeleteMessagesByTransactionIDRequest,
    MessagesControllerDeleteMessagesByTransactionIDRequestTypedDict,
    MessagesControllerDeleteMessagesByTransactionIDResponse,
    MessagesControllerDeleteMessagesByTransactionIDResponseTypedDict,
    QueryParamChannel,
)
from .messagescontroller_getmessagesop import (
    MessagesControllerGetMessagesRequest,
    MessagesControllerGetMessagesRequestTypedDict,
    MessagesControllerGetMessagesResponse,
    MessagesControllerGetMessagesResponseTypedDict,
)
from .messagestatusenum import MessageStatusEnum
from .messagetemplate import MessageTemplate, MessageTemplateTypedDict
from .messagetemplatedto import MessageTemplateDto, MessageTemplateDtoTypedDict
from .monthlytypeenum import MonthlyTypeEnum
from .notificationfeeditemdto import (
    NotificationFeedItemDto,
    NotificationFeedItemDtoStatus,
    NotificationFeedItemDtoTypedDict,
)
from .notificationgroup import NotificationGroup, NotificationGroupTypedDict
from .notificationscontroller_getactivitygraphstatsop import (
    NotificationsControllerGetActivityGraphStatsRequest,
    NotificationsControllerGetActivityGraphStatsRequestTypedDict,
    NotificationsControllerGetActivityGraphStatsResponse,
    NotificationsControllerGetActivityGraphStatsResponseTypedDict,
)
from .notificationscontroller_getactivitystatsop import (
    NotificationsControllerGetActivityStatsRequest,
    NotificationsControllerGetActivityStatsRequestTypedDict,
    NotificationsControllerGetActivityStatsResponse,
    NotificationsControllerGetActivityStatsResponseTypedDict,
)
from .notificationscontroller_getnotificationop import (
    NotificationsControllerGetNotificationRequest,
    NotificationsControllerGetNotificationRequestTypedDict,
    NotificationsControllerGetNotificationResponse,
    NotificationsControllerGetNotificationResponseTypedDict,
)
from .notificationscontroller_listnotificationsop import (
    NotificationsControllerListNotificationsRequest,
    NotificationsControllerListNotificationsRequestTypedDict,
    NotificationsControllerListNotificationsResponse,
    NotificationsControllerListNotificationsResponseTypedDict,
)
from .notificationstepdata import (
    NotificationStepData,
    NotificationStepDataMetadata,
    NotificationStepDataMetadataTypedDict,
    NotificationStepDataTypedDict,
)
from .notificationstepdto import (
    NotificationStepDto,
    NotificationStepDtoMetadata,
    NotificationStepDtoMetadataTypedDict,
    NotificationStepDtoTypedDict,
)
from .notificationtrigger import (
    NotificationTrigger,
    NotificationTriggerType,
    NotificationTriggerTypedDict,
)
from .notificationtriggerdto import (
    NotificationTriggerDto,
    NotificationTriggerDtoTypedDict,
    Type,
)
from .notificationtriggerresponse import (
    NotificationTriggerResponse,
    NotificationTriggerResponseTypedDict,
)
from .notificationtriggervariable import (
    NotificationTriggerVariable,
    NotificationTriggerVariableTypedDict,
)
from .notificationtriggervariableresponse import (
    NotificationTriggerVariableResponse,
    NotificationTriggerVariableResponseType,
    NotificationTriggerVariableResponseTypedDict,
    NotificationTriggerVariableResponseValue,
    NotificationTriggerVariableResponseValueTypedDict,
)
from .ordinalenum import OrdinalEnum
from .ordinalvalueenum import OrdinalValueEnum
from .patchsubscriberrequestdto import (
    PatchSubscriberRequestDto,
    PatchSubscriberRequestDtoData,
    PatchSubscriberRequestDtoDataTypedDict,
    PatchSubscriberRequestDtoTypedDict,
)
from .preference import Preference, PreferenceTypedDict
from .preferencechannels import PreferenceChannels, PreferenceChannelsTypedDict
from .providersidenum import ProvidersIDEnum
from .removesubscriberresponsedto import (
    RemoveSubscriberResponseDto,
    RemoveSubscriberResponseDtoTypedDict,
)
from .removesubscribersrequestdto import (
    RemoveSubscribersRequestDto,
    RemoveSubscribersRequestDtoTypedDict,
)
from .renametopicrequestdto import RenameTopicRequestDto, RenameTopicRequestDtoTypedDict
from .renametopicresponsedto import (
    RenameTopicResponseDto,
    RenameTopicResponseDtoTypedDict,
)
from .replycallback import ReplyCallback, ReplyCallbackTypedDict
from .security import Security, SecurityTypedDict
from .stepfilterdto import StepFilterDto, StepFilterDtoTypedDict, Value
from .steptypeenum import StepTypeEnum
from .subscriberchanneldto import (
    ProviderID,
    SubscriberChannelDto,
    SubscriberChannelDtoTypedDict,
)
from .subscriberfeedresponsedto import (
    SubscriberFeedResponseDto,
    SubscriberFeedResponseDtoTypedDict,
)
from .subscriberpayloaddto import (
    Data,
    DataTypedDict,
    SubscriberPayloadDto,
    SubscriberPayloadDtoTypedDict,
)
from .subscriberresponsedto import SubscriberResponseDto, SubscriberResponseDtoTypedDict
from .subscriberscontroller_getsubscriberop import (
    SubscribersControllerGetSubscriberRequest,
    SubscribersControllerGetSubscriberRequestTypedDict,
    SubscribersControllerGetSubscriberResponse,
    SubscribersControllerGetSubscriberResponseTypedDict,
)
from .subscriberscontroller_patchsubscriberop import (
    SubscribersControllerPatchSubscriberRequest,
    SubscribersControllerPatchSubscriberRequestTypedDict,
    SubscribersControllerPatchSubscriberResponse,
    SubscribersControllerPatchSubscriberResponseTypedDict,
)
from .subscriberscontroller_removesubscriberop import (
    SubscribersControllerRemoveSubscriberRequest,
    SubscribersControllerRemoveSubscriberRequestTypedDict,
    SubscribersControllerRemoveSubscriberResponse,
    SubscribersControllerRemoveSubscriberResponseTypedDict,
)
from .subscriberscontroller_searchsubscribersop import (
    OrderDirection,
    SubscribersControllerSearchSubscribersRequest,
    SubscribersControllerSearchSubscribersRequestTypedDict,
    SubscribersControllerSearchSubscribersResponse,
    SubscribersControllerSearchSubscribersResponseTypedDict,
)
from .subscribersv1controller_bulkcreatesubscribersop import (
    SubscribersV1ControllerBulkCreateSubscribersRequest,
    SubscribersV1ControllerBulkCreateSubscribersRequestTypedDict,
    SubscribersV1ControllerBulkCreateSubscribersResponse,
    SubscribersV1ControllerBulkCreateSubscribersResponseTypedDict,
)
from .subscribersv1controller_chataccessoauthop import (
    SubscribersV1ControllerChatAccessOauthRequest,
    SubscribersV1ControllerChatAccessOauthRequestTypedDict,
    SubscribersV1ControllerChatAccessOauthResponse,
    SubscribersV1ControllerChatAccessOauthResponseTypedDict,
)
from .subscribersv1controller_chatoauthcallbackop import (
    SubscribersV1ControllerChatOauthCallbackRequest,
    SubscribersV1ControllerChatOauthCallbackRequestTypedDict,
    SubscribersV1ControllerChatOauthCallbackResponse,
    SubscribersV1ControllerChatOauthCallbackResponseResult,
    SubscribersV1ControllerChatOauthCallbackResponseResultTypedDict,
    SubscribersV1ControllerChatOauthCallbackResponseTypedDict,
)
from .subscribersv1controller_createsubscriberop import (
    SubscribersV1ControllerCreateSubscriberRequest,
    SubscribersV1ControllerCreateSubscriberRequestTypedDict,
    SubscribersV1ControllerCreateSubscriberResponse,
    SubscribersV1ControllerCreateSubscriberResponseTypedDict,
)
from .subscribersv1controller_deletesubscribercredentialsop import (
    SubscribersV1ControllerDeleteSubscriberCredentialsRequest,
    SubscribersV1ControllerDeleteSubscriberCredentialsRequestTypedDict,
    SubscribersV1ControllerDeleteSubscriberCredentialsResponse,
    SubscribersV1ControllerDeleteSubscriberCredentialsResponseTypedDict,
)
from .subscribersv1controller_getnotificationsfeedop import (
    SubscribersV1ControllerGetNotificationsFeedRequest,
    SubscribersV1ControllerGetNotificationsFeedRequestTypedDict,
    SubscribersV1ControllerGetNotificationsFeedResponse,
    SubscribersV1ControllerGetNotificationsFeedResponseTypedDict,
)
from .subscribersv1controller_getsubscriberop import (
    SubscribersV1ControllerGetSubscriberRequest,
    SubscribersV1ControllerGetSubscriberRequestTypedDict,
    SubscribersV1ControllerGetSubscriberResponse,
    SubscribersV1ControllerGetSubscriberResponseTypedDict,
)
from .subscribersv1controller_getsubscriberpreferencebylevelop import (
    Parameter,
    SubscribersV1ControllerGetSubscriberPreferenceByLevelRequest,
    SubscribersV1ControllerGetSubscriberPreferenceByLevelRequestTypedDict,
    SubscribersV1ControllerGetSubscriberPreferenceByLevelResponse,
    SubscribersV1ControllerGetSubscriberPreferenceByLevelResponseTypedDict,
)
from .subscribersv1controller_getunseencountop import (
    SubscribersV1ControllerGetUnseenCountRequest,
    SubscribersV1ControllerGetUnseenCountRequestTypedDict,
    SubscribersV1ControllerGetUnseenCountResponse,
    SubscribersV1ControllerGetUnseenCountResponseTypedDict,
)
from .subscribersv1controller_listsubscriberpreferencesop import (
    SubscribersV1ControllerListSubscriberPreferencesRequest,
    SubscribersV1ControllerListSubscriberPreferencesRequestTypedDict,
    SubscribersV1ControllerListSubscriberPreferencesResponse,
    SubscribersV1ControllerListSubscriberPreferencesResponseTypedDict,
)
from .subscribersv1controller_listsubscribersop import (
    SubscribersV1ControllerListSubscribersRequest,
    SubscribersV1ControllerListSubscribersRequestTypedDict,
    SubscribersV1ControllerListSubscribersResponse,
    SubscribersV1ControllerListSubscribersResponseBody,
    SubscribersV1ControllerListSubscribersResponseBodyTypedDict,
    SubscribersV1ControllerListSubscribersResponseTypedDict,
)
from .subscribersv1controller_markactionasseenop import (
    SubscribersV1ControllerMarkActionAsSeenRequest,
    SubscribersV1ControllerMarkActionAsSeenRequestTypedDict,
    SubscribersV1ControllerMarkActionAsSeenResponse,
    SubscribersV1ControllerMarkActionAsSeenResponseTypedDict,
)
from .subscribersv1controller_markallunreadasreadop import (
    SubscribersV1ControllerMarkAllUnreadAsReadRequest,
    SubscribersV1ControllerMarkAllUnreadAsReadRequestTypedDict,
    SubscribersV1ControllerMarkAllUnreadAsReadResponse,
    SubscribersV1ControllerMarkAllUnreadAsReadResponseTypedDict,
)
from .subscribersv1controller_markmessagesasop import (
    SubscribersV1ControllerMarkMessagesAsRequest,
    SubscribersV1ControllerMarkMessagesAsRequestTypedDict,
    SubscribersV1ControllerMarkMessagesAsResponse,
    SubscribersV1ControllerMarkMessagesAsResponseTypedDict,
)
from .subscribersv1controller_modifysubscriberchannelop import (
    SubscribersV1ControllerModifySubscriberChannelRequest,
    SubscribersV1ControllerModifySubscriberChannelRequestTypedDict,
    SubscribersV1ControllerModifySubscriberChannelResponse,
    SubscribersV1ControllerModifySubscriberChannelResponseTypedDict,
)
from .subscribersv1controller_removesubscriberop import (
    SubscribersV1ControllerRemoveSubscriberRequest,
    SubscribersV1ControllerRemoveSubscriberRequestTypedDict,
    SubscribersV1ControllerRemoveSubscriberResponse,
    SubscribersV1ControllerRemoveSubscriberResponseTypedDict,
)
from .subscribersv1controller_updatesubscriberchannelop import (
    SubscribersV1ControllerUpdateSubscriberChannelRequest,
    SubscribersV1ControllerUpdateSubscriberChannelRequestTypedDict,
    SubscribersV1ControllerUpdateSubscriberChannelResponse,
    SubscribersV1ControllerUpdateSubscriberChannelResponseTypedDict,
)
from .subscribersv1controller_updatesubscriberglobalpreferencesop import (
    SubscribersV1ControllerUpdateSubscriberGlobalPreferencesRequest,
    SubscribersV1ControllerUpdateSubscriberGlobalPreferencesRequestTypedDict,
    SubscribersV1ControllerUpdateSubscriberGlobalPreferencesResponse,
    SubscribersV1ControllerUpdateSubscriberGlobalPreferencesResponseTypedDict,
)
from .subscribersv1controller_updatesubscriberonlineflagop import (
    SubscribersV1ControllerUpdateSubscriberOnlineFlagRequest,
    SubscribersV1ControllerUpdateSubscriberOnlineFlagRequestTypedDict,
    SubscribersV1ControllerUpdateSubscriberOnlineFlagResponse,
    SubscribersV1ControllerUpdateSubscriberOnlineFlagResponseTypedDict,
)
from .subscribersv1controller_updatesubscriberop import (
    SubscribersV1ControllerUpdateSubscriberRequest,
    SubscribersV1ControllerUpdateSubscriberRequestTypedDict,
    SubscribersV1ControllerUpdateSubscriberResponse,
    SubscribersV1ControllerUpdateSubscriberResponseTypedDict,
)
from .subscribersv1controller_updatesubscriberpreferenceop import (
    SubscribersV1ControllerUpdateSubscriberPreferenceRequest,
    SubscribersV1ControllerUpdateSubscriberPreferenceRequestTypedDict,
    SubscribersV1ControllerUpdateSubscriberPreferenceResponse,
    SubscribersV1ControllerUpdateSubscriberPreferenceResponseTypedDict,
)
from .templateresponse import TemplateResponse, TemplateResponseTypedDict
from .tenantpayloaddto import (
    TenantPayloadDto,
    TenantPayloadDtoData,
    TenantPayloadDtoDataTypedDict,
    TenantPayloadDtoTypedDict,
)
from .textalignenum import TextAlignEnum
from .timedconfig import (
    MonthlyType,
    Ordinal,
    OrdinalValue,
    TimedConfig,
    TimedConfigTypedDict,
    TimedConfigWeekDays,
)
from .topicdto import TopicDto, TopicDtoTypedDict
from .topicpayloaddto import TopicPayloadDto, TopicPayloadDtoTypedDict
from .topicscontroller_assignop import (
    TopicsControllerAssignRequest,
    TopicsControllerAssignRequestTypedDict,
    TopicsControllerAssignResponse,
    TopicsControllerAssignResponseTypedDict,
)
from .topicscontroller_createtopicop import (
    TopicsControllerCreateTopicRequest,
    TopicsControllerCreateTopicRequestTypedDict,
    TopicsControllerCreateTopicResponse,
    TopicsControllerCreateTopicResponseTypedDict,
)
from .topicscontroller_deletetopicop import (
    TopicsControllerDeleteTopicRequest,
    TopicsControllerDeleteTopicRequestTypedDict,
    TopicsControllerDeleteTopicResponse,
    TopicsControllerDeleteTopicResponseTypedDict,
)
from .topicscontroller_gettopicop import (
    TopicsControllerGetTopicRequest,
    TopicsControllerGetTopicRequestTypedDict,
    TopicsControllerGetTopicResponse,
    TopicsControllerGetTopicResponseTypedDict,
)
from .topicscontroller_gettopicsubscriberop import (
    TopicsControllerGetTopicSubscriberRequest,
    TopicsControllerGetTopicSubscriberRequestTypedDict,
    TopicsControllerGetTopicSubscriberResponse,
    TopicsControllerGetTopicSubscriberResponseTypedDict,
)
from .topicscontroller_listtopicsop import (
    TopicsControllerListTopicsRequest,
    TopicsControllerListTopicsRequestTypedDict,
    TopicsControllerListTopicsResponse,
    TopicsControllerListTopicsResponseTypedDict,
)
from .topicscontroller_removesubscribersop import (
    TopicsControllerRemoveSubscribersRequest,
    TopicsControllerRemoveSubscribersRequestTypedDict,
    TopicsControllerRemoveSubscribersResponse,
    TopicsControllerRemoveSubscribersResponseTypedDict,
)
from .topicscontroller_renametopicop import (
    TopicsControllerRenameTopicRequest,
    TopicsControllerRenameTopicRequestTypedDict,
    TopicsControllerRenameTopicResponse,
    TopicsControllerRenameTopicResponseTypedDict,
)
from .topicsubscriberdto import TopicSubscriberDto, TopicSubscriberDtoTypedDict
from .triggereventrequestdto import (
    Actor,
    ActorTypedDict,
    One,
    OneTypedDict,
    Tenant,
    TenantTypedDict,
    To,
    ToTypedDict,
    TriggerEventRequestDto,
    TriggerEventRequestDtoTypedDict,
)
from .triggereventresponsedto import (
    Status,
    TriggerEventResponseDto,
    TriggerEventResponseDtoTypedDict,
)
from .triggereventtoallrequestdto import (
    Overrides,
    OverridesTypedDict,
    TriggerEventToAllRequestDto,
    TriggerEventToAllRequestDtoActor,
    TriggerEventToAllRequestDtoActorTypedDict,
    TriggerEventToAllRequestDtoTenant,
    TriggerEventToAllRequestDtoTenantTypedDict,
    TriggerEventToAllRequestDtoTypedDict,
)
from .triggerrecipientstypeenum import TriggerRecipientsTypeEnum
from .triggerreservedvariableresponse import (
    TriggerReservedVariableResponse,
    TriggerReservedVariableResponseType,
    TriggerReservedVariableResponseTypedDict,
)
from .triggertypeenum import TriggerTypeEnum
from .unseencountresponse import UnseenCountResponse, UnseenCountResponseTypedDict
from .updatedsubscriberdto import UpdatedSubscriberDto, UpdatedSubscriberDtoTypedDict
from .updateintegrationrequestdto import (
    UpdateIntegrationRequestDto,
    UpdateIntegrationRequestDtoTypedDict,
)
from .updatesubscriberchannelrequestdto import (
    UpdateSubscriberChannelRequestDto,
    UpdateSubscriberChannelRequestDtoProviderID,
    UpdateSubscriberChannelRequestDtoTypedDict,
)
from .updatesubscriberglobalpreferencesrequestdto import (
    UpdateSubscriberGlobalPreferencesRequestDto,
    UpdateSubscriberGlobalPreferencesRequestDtoTypedDict,
)
from .updatesubscriberonlineflagrequestdto import (
    UpdateSubscriberOnlineFlagRequestDto,
    UpdateSubscriberOnlineFlagRequestDtoTypedDict,
)
from .updatesubscriberpreferenceglobalresponsedto import (
    UpdateSubscriberPreferenceGlobalResponseDto,
    UpdateSubscriberPreferenceGlobalResponseDtoTypedDict,
)
from .updatesubscriberpreferencerequestdto import (
    UpdateSubscriberPreferenceRequestDto,
    UpdateSubscriberPreferenceRequestDtoTypedDict,
)
from .updatesubscriberpreferenceresponsedto import (
    UpdateSubscriberPreferenceResponseDto,
    UpdateSubscriberPreferenceResponseDtoTypedDict,
)
from .updatesubscriberrequestdto import (
    UpdateSubscriberRequestDto,
    UpdateSubscriberRequestDtoTypedDict,
)
from .validationerrordto import (
    Errors,
    ErrorsTypedDict,
    ValidationErrorDto,
    ValidationErrorDtoData,
    ValidationErrorDtoValue,
)
from .workflowresponse import (
    WorkflowIntegrationStatus,
    WorkflowIntegrationStatusTypedDict,
    WorkflowResponse,
    WorkflowResponseData,
    WorkflowResponseDataTypedDict,
    WorkflowResponseTypedDict,
)


__all__ = [
    "APIError",
    "ActivitiesResponseDto",
    "ActivitiesResponseDtoTypedDict",
    "ActivityGraphStatesResponse",
    "ActivityGraphStatesResponseTypedDict",
    "ActivityNotificationExecutionDetailResponseDto",
    "ActivityNotificationExecutionDetailResponseDtoTypedDict",
    "ActivityNotificationJobResponseDto",
    "ActivityNotificationJobResponseDtoType",
    "ActivityNotificationJobResponseDtoTypedDict",
    "ActivityNotificationResponseDto",
    "ActivityNotificationResponseDtoPayload",
    "ActivityNotificationResponseDtoPayloadTypedDict",
    "ActivityNotificationResponseDtoTo",
    "ActivityNotificationResponseDtoToTypedDict",
    "ActivityNotificationResponseDtoTypedDict",
    "ActivityNotificationStepResponseDto",
    "ActivityNotificationStepResponseDtoReplyCallback",
    "ActivityNotificationStepResponseDtoReplyCallbackTypedDict",
    "ActivityNotificationStepResponseDtoTypedDict",
    "ActivityNotificationSubscriberResponseDto",
    "ActivityNotificationSubscriberResponseDtoTypedDict",
    "ActivityNotificationTemplateResponseDto",
    "ActivityNotificationTemplateResponseDtoTypedDict",
    "ActivityStatsResponseDto",
    "ActivityStatsResponseDtoTypedDict",
    "Actor",
    "ActorFeedItemDto",
    "ActorFeedItemDtoTypedDict",
    "ActorTypeEnum",
    "ActorTypedDict",
    "AddSubscribersRequestDto",
    "AddSubscribersRequestDtoTypedDict",
    "AssignSubscriberToTopicDto",
    "AssignSubscriberToTopicDtoTypedDict",
    "BackoffUnit",
    "BuilderFieldTypeEnum",
    "BulkCreateSubscriberResponseDto",
    "BulkCreateSubscriberResponseDtoTypedDict",
    "BulkSubscriberCreateDto",
    "BulkSubscriberCreateDtoTypedDict",
    "BulkTriggerEventDto",
    "BulkTriggerEventDtoTypedDict",
    "ButtonTypeEnum",
    "Channel",
    "ChannelCTATypeEnum",
    "ChannelCredentials",
    "ChannelCredentialsDto",
    "ChannelCredentialsDtoTypedDict",
    "ChannelCredentialsTypedDict",
    "ChannelPreference",
    "ChannelPreferenceTypedDict",
    "ChannelSettingsDto",
    "ChannelSettingsDtoProviderID",
    "ChannelSettingsDtoTypedDict",
    "ChannelTypeEnum",
    "Channels",
    "Content",
    "ContentTypedDict",
    "ControlVariables",
    "ControlVariablesTypedDict",
    "Controls",
    "ControlsTypedDict",
    "CreateIntegrationRequestDto",
    "CreateIntegrationRequestDtoChannel",
    "CreateIntegrationRequestDtoTypedDict",
    "CreateSubscriberRequestDto",
    "CreateSubscriberRequestDtoData",
    "CreateSubscriberRequestDtoDataTypedDict",
    "CreateSubscriberRequestDtoTypedDict",
    "CreateTopicRequestDto",
    "CreateTopicRequestDtoTypedDict",
    "CreateTopicResponseDto",
    "CreateTopicResponseDtoTypedDict",
    "CreatedSubscriberDto",
    "CreatedSubscriberDtoTypedDict",
    "CredentialsDto",
    "CredentialsDtoTypedDict",
    "Data",
    "DataBooleanDto",
    "DataBooleanDtoTypedDict",
    "DataTypedDict",
    "DelayRegularMetadata",
    "DelayRegularMetadataType",
    "DelayRegularMetadataTypedDict",
    "DelayRegularMetadataUnit",
    "DelayScheduledMetadata",
    "DelayScheduledMetadataType",
    "DelayScheduledMetadataTypedDict",
    "DeleteMessageResponseDto",
    "DeleteMessageResponseDtoStatus",
    "DeleteMessageResponseDtoTypedDict",
    "DeleteSubscriberResponseDto",
    "DeleteSubscriberResponseDtoStatus",
    "DeleteSubscriberResponseDtoTypedDict",
    "DigestMetadataDto",
    "DigestMetadataDtoTypedDict",
    "DigestRegularMetadata",
    "DigestRegularMetadataType",
    "DigestRegularMetadataTypedDict",
    "DigestRegularMetadataUnit",
    "DigestTimedConfigDto",
    "DigestTimedConfigDtoTypedDict",
    "DigestTimedMetadata",
    "DigestTimedMetadataType",
    "DigestTimedMetadataTypedDict",
    "DigestTimedMetadataUnit",
    "DigestTypeEnum",
    "DigestUnitEnum",
    "EmailBlock",
    "EmailBlockStyles",
    "EmailBlockStylesTypedDict",
    "EmailBlockTypeEnum",
    "EmailBlockTypedDict",
    "ErrorDto",
    "ErrorDtoData",
    "Errors",
    "ErrorsTypedDict",
    "EventsControllerBroadcastEventToAllRequest",
    "EventsControllerBroadcastEventToAllRequestTypedDict",
    "EventsControllerBroadcastEventToAllResponse",
    "EventsControllerBroadcastEventToAllResponseTypedDict",
    "EventsControllerCancelRequest",
    "EventsControllerCancelRequestTypedDict",
    "EventsControllerCancelResponse",
    "EventsControllerCancelResponseTypedDict",
    "EventsControllerTriggerBulkRequest",
    "EventsControllerTriggerBulkRequestTypedDict",
    "EventsControllerTriggerBulkResponse",
    "EventsControllerTriggerBulkResponseTypedDict",
    "EventsControllerTriggerRequest",
    "EventsControllerTriggerRequestTypedDict",
    "EventsControllerTriggerResponse",
    "EventsControllerTriggerResponseTypedDict",
    "ExecutionDetailsSourceEnum",
    "ExecutionDetailsStatusEnum",
    "FailedAssignmentsDto",
    "FailedAssignmentsDtoTypedDict",
    "FailedOperationDto",
    "FailedOperationDtoTypedDict",
    "FeedIdentifier",
    "FeedIdentifierTypedDict",
    "FeedResponseDto",
    "FeedResponseDtoTypedDict",
    "FieldFilterPartDto",
    "FieldFilterPartDtoTypedDict",
    "FilterTopicsResponseDto",
    "FilterTopicsResponseDtoTypedDict",
    "GetSubscriberPreferencesResponseDto",
    "GetSubscriberPreferencesResponseDtoTypedDict",
    "GetTopicResponseDto",
    "GetTopicResponseDtoTypedDict",
    "IntegrationResponseDto",
    "IntegrationResponseDtoTypedDict",
    "IntegrationsControllerCreateIntegrationRequest",
    "IntegrationsControllerCreateIntegrationRequestTypedDict",
    "IntegrationsControllerCreateIntegrationResponse",
    "IntegrationsControllerCreateIntegrationResponseTypedDict",
    "IntegrationsControllerGetActiveIntegrationsRequest",
    "IntegrationsControllerGetActiveIntegrationsRequestTypedDict",
    "IntegrationsControllerGetActiveIntegrationsResponse",
    "IntegrationsControllerGetActiveIntegrationsResponseTypedDict",
    "IntegrationsControllerGetWebhookSupportStatusRequest",
    "IntegrationsControllerGetWebhookSupportStatusRequestTypedDict",
    "IntegrationsControllerGetWebhookSupportStatusResponse",
    "IntegrationsControllerGetWebhookSupportStatusResponseTypedDict",
    "IntegrationsControllerListIntegrationsRequest",
    "IntegrationsControllerListIntegrationsRequestTypedDict",
    "IntegrationsControllerListIntegrationsResponse",
    "IntegrationsControllerListIntegrationsResponseTypedDict",
    "IntegrationsControllerRemoveIntegrationRequest",
    "IntegrationsControllerRemoveIntegrationRequestTypedDict",
    "IntegrationsControllerRemoveIntegrationResponse",
    "IntegrationsControllerRemoveIntegrationResponseTypedDict",
    "IntegrationsControllerSetIntegrationAsPrimaryRequest",
    "IntegrationsControllerSetIntegrationAsPrimaryRequestTypedDict",
    "IntegrationsControllerSetIntegrationAsPrimaryResponse",
    "IntegrationsControllerSetIntegrationAsPrimaryResponseTypedDict",
    "IntegrationsControllerUpdateIntegrationByIDRequest",
    "IntegrationsControllerUpdateIntegrationByIDRequestTypedDict",
    "IntegrationsControllerUpdateIntegrationByIDResponse",
    "IntegrationsControllerUpdateIntegrationByIDResponseTypedDict",
    "Issues",
    "IssuesTypedDict",
    "ListSubscribersResponseDto",
    "ListSubscribersResponseDtoTypedDict",
    "MarkAllMessageAsRequestDto",
    "MarkAllMessageAsRequestDtoMarkAs",
    "MarkAllMessageAsRequestDtoTypedDict",
    "MarkAs",
    "MarkMessageActionAsSeenDto",
    "MarkMessageActionAsSeenDtoPayload",
    "MarkMessageActionAsSeenDtoPayloadTypedDict",
    "MarkMessageActionAsSeenDtoStatus",
    "MarkMessageActionAsSeenDtoTypedDict",
    "MessageAction",
    "MessageActionResult",
    "MessageActionResultPayload",
    "MessageActionResultPayloadTypedDict",
    "MessageActionResultTypedDict",
    "MessageActionStatusEnum",
    "MessageActionTypedDict",
    "MessageButton",
    "MessageButtonTypedDict",
    "MessageCTA",
    "MessageCTAData",
    "MessageCTADataTypedDict",
    "MessageCTATypedDict",
    "MessageID",
    "MessageIDTypedDict",
    "MessageMarkAsRequestDto",
    "MessageMarkAsRequestDtoTypedDict",
    "MessageResponseDto",
    "MessageResponseDtoOverrides",
    "MessageResponseDtoOverridesTypedDict",
    "MessageResponseDtoPayload",
    "MessageResponseDtoPayloadTypedDict",
    "MessageResponseDtoTypedDict",
    "MessageStatusEnum",
    "MessageTemplate",
    "MessageTemplateDto",
    "MessageTemplateDtoTypedDict",
    "MessageTemplateTypedDict",
    "MessagesControllerDeleteMessageRequest",
    "MessagesControllerDeleteMessageRequestTypedDict",
    "MessagesControllerDeleteMessageResponse",
    "MessagesControllerDeleteMessageResponseTypedDict",
    "MessagesControllerDeleteMessagesByTransactionIDRequest",
    "MessagesControllerDeleteMessagesByTransactionIDRequestTypedDict",
    "MessagesControllerDeleteMessagesByTransactionIDResponse",
    "MessagesControllerDeleteMessagesByTransactionIDResponseTypedDict",
    "MessagesControllerGetMessagesRequest",
    "MessagesControllerGetMessagesRequestTypedDict",
    "MessagesControllerGetMessagesResponse",
    "MessagesControllerGetMessagesResponseTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "MonthlyType",
    "MonthlyTypeEnum",
    "NotificationFeedItemDto",
    "NotificationFeedItemDtoStatus",
    "NotificationFeedItemDtoTypedDict",
    "NotificationGroup",
    "NotificationGroupTypedDict",
    "NotificationStepData",
    "NotificationStepDataMetadata",
    "NotificationStepDataMetadataTypedDict",
    "NotificationStepDataTypedDict",
    "NotificationStepDto",
    "NotificationStepDtoMetadata",
    "NotificationStepDtoMetadataTypedDict",
    "NotificationStepDtoTypedDict",
    "NotificationTrigger",
    "NotificationTriggerDto",
    "NotificationTriggerDtoTypedDict",
    "NotificationTriggerResponse",
    "NotificationTriggerResponseTypedDict",
    "NotificationTriggerType",
    "NotificationTriggerTypedDict",
    "NotificationTriggerVariable",
    "NotificationTriggerVariableResponse",
    "NotificationTriggerVariableResponseType",
    "NotificationTriggerVariableResponseTypedDict",
    "NotificationTriggerVariableResponseValue",
    "NotificationTriggerVariableResponseValueTypedDict",
    "NotificationTriggerVariableTypedDict",
    "NotificationsControllerGetActivityGraphStatsRequest",
    "NotificationsControllerGetActivityGraphStatsRequestTypedDict",
    "NotificationsControllerGetActivityGraphStatsResponse",
    "NotificationsControllerGetActivityGraphStatsResponseTypedDict",
    "NotificationsControllerGetActivityStatsRequest",
    "NotificationsControllerGetActivityStatsRequestTypedDict",
    "NotificationsControllerGetActivityStatsResponse",
    "NotificationsControllerGetActivityStatsResponseTypedDict",
    "NotificationsControllerGetNotificationRequest",
    "NotificationsControllerGetNotificationRequestTypedDict",
    "NotificationsControllerGetNotificationResponse",
    "NotificationsControllerGetNotificationResponseTypedDict",
    "NotificationsControllerListNotificationsRequest",
    "NotificationsControllerListNotificationsRequestTypedDict",
    "NotificationsControllerListNotificationsResponse",
    "NotificationsControllerListNotificationsResponseTypedDict",
    "On",
    "One",
    "OneTypedDict",
    "Operator",
    "OrderDirection",
    "Ordinal",
    "OrdinalEnum",
    "OrdinalValue",
    "OrdinalValueEnum",
    "Overrides",
    "OverridesTypedDict",
    "Parameter",
    "PatchSubscriberRequestDto",
    "PatchSubscriberRequestDtoData",
    "PatchSubscriberRequestDtoDataTypedDict",
    "PatchSubscriberRequestDtoTypedDict",
    "Payload",
    "PayloadTypedDict",
    "Preference",
    "PreferenceChannels",
    "PreferenceChannelsTypedDict",
    "PreferenceTypedDict",
    "ProviderID",
    "ProvidersIDEnum",
    "QueryParamChannel",
    "RemoveSubscriberResponseDto",
    "RemoveSubscriberResponseDtoTypedDict",
    "RemoveSubscribersRequestDto",
    "RemoveSubscribersRequestDtoTypedDict",
    "RenameTopicRequestDto",
    "RenameTopicRequestDtoTypedDict",
    "RenameTopicResponseDto",
    "RenameTopicResponseDtoTypedDict",
    "ReplyCallback",
    "ReplyCallbackTypedDict",
    "Security",
    "SecurityTypedDict",
    "Status",
    "StepFilterDto",
    "StepFilterDtoTypedDict",
    "StepTypeEnum",
    "SubscriberChannelDto",
    "SubscriberChannelDtoTypedDict",
    "SubscriberFeedResponseDto",
    "SubscriberFeedResponseDtoTypedDict",
    "SubscriberPayloadDto",
    "SubscriberPayloadDtoTypedDict",
    "SubscriberResponseDto",
    "SubscriberResponseDtoTypedDict",
    "SubscribersControllerGetSubscriberRequest",
    "SubscribersControllerGetSubscriberRequestTypedDict",
    "SubscribersControllerGetSubscriberResponse",
    "SubscribersControllerGetSubscriberResponseTypedDict",
    "SubscribersControllerPatchSubscriberRequest",
    "SubscribersControllerPatchSubscriberRequestTypedDict",
    "SubscribersControllerPatchSubscriberResponse",
    "SubscribersControllerPatchSubscriberResponseTypedDict",
    "SubscribersControllerRemoveSubscriberRequest",
    "SubscribersControllerRemoveSubscriberRequestTypedDict",
    "SubscribersControllerRemoveSubscriberResponse",
    "SubscribersControllerRemoveSubscriberResponseTypedDict",
    "SubscribersControllerSearchSubscribersRequest",
    "SubscribersControllerSearchSubscribersRequestTypedDict",
    "SubscribersControllerSearchSubscribersResponse",
    "SubscribersControllerSearchSubscribersResponseTypedDict",
    "SubscribersV1ControllerBulkCreateSubscribersRequest",
    "SubscribersV1ControllerBulkCreateSubscribersRequestTypedDict",
    "SubscribersV1ControllerBulkCreateSubscribersResponse",
    "SubscribersV1ControllerBulkCreateSubscribersResponseTypedDict",
    "SubscribersV1ControllerChatAccessOauthRequest",
    "SubscribersV1ControllerChatAccessOauthRequestTypedDict",
    "SubscribersV1ControllerChatAccessOauthResponse",
    "SubscribersV1ControllerChatAccessOauthResponseTypedDict",
    "SubscribersV1ControllerChatOauthCallbackRequest",
    "SubscribersV1ControllerChatOauthCallbackRequestTypedDict",
    "SubscribersV1ControllerChatOauthCallbackResponse",
    "SubscribersV1ControllerChatOauthCallbackResponseResult",
    "SubscribersV1ControllerChatOauthCallbackResponseResultTypedDict",
    "SubscribersV1ControllerChatOauthCallbackResponseTypedDict",
    "SubscribersV1ControllerCreateSubscriberRequest",
    "SubscribersV1ControllerCreateSubscriberRequestTypedDict",
    "SubscribersV1ControllerCreateSubscriberResponse",
    "SubscribersV1ControllerCreateSubscriberResponseTypedDict",
    "SubscribersV1ControllerDeleteSubscriberCredentialsRequest",
    "SubscribersV1ControllerDeleteSubscriberCredentialsRequestTypedDict",
    "SubscribersV1ControllerDeleteSubscriberCredentialsResponse",
    "SubscribersV1ControllerDeleteSubscriberCredentialsResponseTypedDict",
    "SubscribersV1ControllerGetNotificationsFeedRequest",
    "SubscribersV1ControllerGetNotificationsFeedRequestTypedDict",
    "SubscribersV1ControllerGetNotificationsFeedResponse",
    "SubscribersV1ControllerGetNotificationsFeedResponseTypedDict",
    "SubscribersV1ControllerGetSubscriberPreferenceByLevelRequest",
    "SubscribersV1ControllerGetSubscriberPreferenceByLevelRequestTypedDict",
    "SubscribersV1ControllerGetSubscriberPreferenceByLevelResponse",
    "SubscribersV1ControllerGetSubscriberPreferenceByLevelResponseTypedDict",
    "SubscribersV1ControllerGetSubscriberRequest",
    "SubscribersV1ControllerGetSubscriberRequestTypedDict",
    "SubscribersV1ControllerGetSubscriberResponse",
    "SubscribersV1ControllerGetSubscriberResponseTypedDict",
    "SubscribersV1ControllerGetUnseenCountRequest",
    "SubscribersV1ControllerGetUnseenCountRequestTypedDict",
    "SubscribersV1ControllerGetUnseenCountResponse",
    "SubscribersV1ControllerGetUnseenCountResponseTypedDict",
    "SubscribersV1ControllerListSubscriberPreferencesRequest",
    "SubscribersV1ControllerListSubscriberPreferencesRequestTypedDict",
    "SubscribersV1ControllerListSubscriberPreferencesResponse",
    "SubscribersV1ControllerListSubscriberPreferencesResponseTypedDict",
    "SubscribersV1ControllerListSubscribersRequest",
    "SubscribersV1ControllerListSubscribersRequestTypedDict",
    "SubscribersV1ControllerListSubscribersResponse",
    "SubscribersV1ControllerListSubscribersResponseBody",
    "SubscribersV1ControllerListSubscribersResponseBodyTypedDict",
    "SubscribersV1ControllerListSubscribersResponseTypedDict",
    "SubscribersV1ControllerMarkActionAsSeenRequest",
    "SubscribersV1ControllerMarkActionAsSeenRequestTypedDict",
    "SubscribersV1ControllerMarkActionAsSeenResponse",
    "SubscribersV1ControllerMarkActionAsSeenResponseTypedDict",
    "SubscribersV1ControllerMarkAllUnreadAsReadRequest",
    "SubscribersV1ControllerMarkAllUnreadAsReadRequestTypedDict",
    "SubscribersV1ControllerMarkAllUnreadAsReadResponse",
    "SubscribersV1ControllerMarkAllUnreadAsReadResponseTypedDict",
    "SubscribersV1ControllerMarkMessagesAsRequest",
    "SubscribersV1ControllerMarkMessagesAsRequestTypedDict",
    "SubscribersV1ControllerMarkMessagesAsResponse",
    "SubscribersV1ControllerMarkMessagesAsResponseTypedDict",
    "SubscribersV1ControllerModifySubscriberChannelRequest",
    "SubscribersV1ControllerModifySubscriberChannelRequestTypedDict",
    "SubscribersV1ControllerModifySubscriberChannelResponse",
    "SubscribersV1ControllerModifySubscriberChannelResponseTypedDict",
    "SubscribersV1ControllerRemoveSubscriberRequest",
    "SubscribersV1ControllerRemoveSubscriberRequestTypedDict",
    "SubscribersV1ControllerRemoveSubscriberResponse",
    "SubscribersV1ControllerRemoveSubscriberResponseTypedDict",
    "SubscribersV1ControllerUpdateSubscriberChannelRequest",
    "SubscribersV1ControllerUpdateSubscriberChannelRequestTypedDict",
    "SubscribersV1ControllerUpdateSubscriberChannelResponse",
    "SubscribersV1ControllerUpdateSubscriberChannelResponseTypedDict",
    "SubscribersV1ControllerUpdateSubscriberGlobalPreferencesRequest",
    "SubscribersV1ControllerUpdateSubscriberGlobalPreferencesRequestTypedDict",
    "SubscribersV1ControllerUpdateSubscriberGlobalPreferencesResponse",
    "SubscribersV1ControllerUpdateSubscriberGlobalPreferencesResponseTypedDict",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagRequest",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagRequestTypedDict",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagResponse",
    "SubscribersV1ControllerUpdateSubscriberOnlineFlagResponseTypedDict",
    "SubscribersV1ControllerUpdateSubscriberPreferenceRequest",
    "SubscribersV1ControllerUpdateSubscriberPreferenceRequestTypedDict",
    "SubscribersV1ControllerUpdateSubscriberPreferenceResponse",
    "SubscribersV1ControllerUpdateSubscriberPreferenceResponseTypedDict",
    "SubscribersV1ControllerUpdateSubscriberRequest",
    "SubscribersV1ControllerUpdateSubscriberRequestTypedDict",
    "SubscribersV1ControllerUpdateSubscriberResponse",
    "SubscribersV1ControllerUpdateSubscriberResponseTypedDict",
    "TLSOptions",
    "TLSOptionsTypedDict",
    "TemplateResponse",
    "TemplateResponseTypedDict",
    "Tenant",
    "TenantPayloadDto",
    "TenantPayloadDtoData",
    "TenantPayloadDtoDataTypedDict",
    "TenantPayloadDtoTypedDict",
    "TenantTypedDict",
    "TextAlignEnum",
    "TimedConfig",
    "TimedConfigTypedDict",
    "TimedConfigWeekDays",
    "To",
    "ToTypedDict",
    "TopicDto",
    "TopicDtoTypedDict",
    "TopicPayloadDto",
    "TopicPayloadDtoTypedDict",
    "TopicSubscriberDto",
    "TopicSubscriberDtoTypedDict",
    "TopicsControllerAssignRequest",
    "TopicsControllerAssignRequestTypedDict",
    "TopicsControllerAssignResponse",
    "TopicsControllerAssignResponseTypedDict",
    "TopicsControllerCreateTopicRequest",
    "TopicsControllerCreateTopicRequestTypedDict",
    "TopicsControllerCreateTopicResponse",
    "TopicsControllerCreateTopicResponseTypedDict",
    "TopicsControllerDeleteTopicRequest",
    "TopicsControllerDeleteTopicRequestTypedDict",
    "TopicsControllerDeleteTopicResponse",
    "TopicsControllerDeleteTopicResponseTypedDict",
    "TopicsControllerGetTopicRequest",
    "TopicsControllerGetTopicRequestTypedDict",
    "TopicsControllerGetTopicResponse",
    "TopicsControllerGetTopicResponseTypedDict",
    "TopicsControllerGetTopicSubscriberRequest",
    "TopicsControllerGetTopicSubscriberRequestTypedDict",
    "TopicsControllerGetTopicSubscriberResponse",
    "TopicsControllerGetTopicSubscriberResponseTypedDict",
    "TopicsControllerListTopicsRequest",
    "TopicsControllerListTopicsRequestTypedDict",
    "TopicsControllerListTopicsResponse",
    "TopicsControllerListTopicsResponseTypedDict",
    "TopicsControllerRemoveSubscribersRequest",
    "TopicsControllerRemoveSubscribersRequestTypedDict",
    "TopicsControllerRemoveSubscribersResponse",
    "TopicsControllerRemoveSubscribersResponseTypedDict",
    "TopicsControllerRenameTopicRequest",
    "TopicsControllerRenameTopicRequestTypedDict",
    "TopicsControllerRenameTopicResponse",
    "TopicsControllerRenameTopicResponseTypedDict",
    "TriggerEventRequestDto",
    "TriggerEventRequestDtoTypedDict",
    "TriggerEventResponseDto",
    "TriggerEventResponseDtoTypedDict",
    "TriggerEventToAllRequestDto",
    "TriggerEventToAllRequestDtoActor",
    "TriggerEventToAllRequestDtoActorTypedDict",
    "TriggerEventToAllRequestDtoTenant",
    "TriggerEventToAllRequestDtoTenantTypedDict",
    "TriggerEventToAllRequestDtoTypedDict",
    "TriggerRecipientsTypeEnum",
    "TriggerReservedVariableResponse",
    "TriggerReservedVariableResponseType",
    "TriggerReservedVariableResponseTypedDict",
    "TriggerTypeEnum",
    "Type",
    "Unit",
    "UnseenCountResponse",
    "UnseenCountResponseTypedDict",
    "UpdateIntegrationRequestDto",
    "UpdateIntegrationRequestDtoTypedDict",
    "UpdateSubscriberChannelRequestDto",
    "UpdateSubscriberChannelRequestDtoProviderID",
    "UpdateSubscriberChannelRequestDtoTypedDict",
    "UpdateSubscriberGlobalPreferencesRequestDto",
    "UpdateSubscriberGlobalPreferencesRequestDtoTypedDict",
    "UpdateSubscriberOnlineFlagRequestDto",
    "UpdateSubscriberOnlineFlagRequestDtoTypedDict",
    "UpdateSubscriberPreferenceGlobalResponseDto",
    "UpdateSubscriberPreferenceGlobalResponseDtoTypedDict",
    "UpdateSubscriberPreferenceRequestDto",
    "UpdateSubscriberPreferenceRequestDtoTypedDict",
    "UpdateSubscriberPreferenceResponseDto",
    "UpdateSubscriberPreferenceResponseDtoTypedDict",
    "UpdateSubscriberRequestDto",
    "UpdateSubscriberRequestDtoTypedDict",
    "UpdatedSubscriberDto",
    "UpdatedSubscriberDtoTypedDict",
    "ValidationErrorDto",
    "ValidationErrorDtoData",
    "ValidationErrorDtoValue",
    "Value",
    "WeekDays",
    "WorkflowIntegrationStatus",
    "WorkflowIntegrationStatusTypedDict",
    "WorkflowResponse",
    "WorkflowResponseData",
    "WorkflowResponseDataTypedDict",
    "WorkflowResponseTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .preference import Preference, PreferenceTypedDict
from .templateresponse import TemplateResponse, TemplateResponseTypedDict
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class UpdateSubscriberPreferenceResponseDtoTypedDict(TypedDict):
    template: TemplateResponseTypedDict
    r"""The workflow information and if it is critical or not"""
    preference: PreferenceTypedDict
    r"""The preferences of the subscriber regarding the related workflow"""


class UpdateSubscriberPreferenceResponseDto(BaseModel):
    template: TemplateResponse
    r"""The workflow information and if it is critical or not"""

    preference: Preference
    r"""The preferences of the subscriber regarding the related workflow"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .preferencechannels import PreferenceChannels, PreferenceChannelsTypedDict
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class PreferenceTypedDict(TypedDict):
    enabled: bool
    r"""Sets if the workflow is fully enabled for all channels or not for the subscriber."""
    channels: PreferenceChannelsTypedDict
    r"""Subscriber preferences for the different channels regarding this workflow"""


class Preference(BaseModel):
    enabled: bool
    r"""Sets if the workflow is fully enabled for all channels or not for the subscriber."""

    channels: PreferenceChannels
    r"""Subscriber preferences for the different channels regarding this workflow"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FailedAssignmentsDtoTypedDict(TypedDict):
    not_found: NotRequired[List[str]]
    r"""List of subscriber IDs that were not found"""


class FailedAssignmentsDto(BaseModel):
    not_found: Annotated[Optional[List[str]], pydantic.Field(alias="notFound")] = None
    r"""List of subscriber IDs that were not found"""
